@@ -18,6 +18,12 @@ TEMPLATES = {
     },
     TMPL_DIR / 'pyproject.tmpl': {
         'path': Path('pyproject.toml'),
+    },
+    TMPL_DIR / 'projectile.tmpl': {
+        'path': Path('.projectile'),
+    },
+    TMPL_DIR / 'isort.tmpl': {
+        'path': Path('.isort.cfg'),
     }
 }
 
